@@ -264,6 +264,9 @@ class WorkbenchMenu:
     def list_all_datasets(self):
         """List the complete set of datasets which have been indexed by the workbench."""
 
+        # Make sure that all datasets have been populated from the home directory
+        self.wb.datasets.populate()
+
         # Print:
         #   Dataset tree beneath the cwd
         print(self.wb.datasets.format_dataset_tree())
